Struct ExistsColumnBuilder
pub struct ExistsColumnBuilder<T> { /* private fields */ }Expand description
Builder for EXISTS columns in JSON_TABLE
Implementations
impl<T> ExistsColumnBuilder<T>
impl<T> ExistsColumnBuilder<T>
pub fn error_on_error(self) -> Self
pub fn error_on_error(self) -> Self
Convenience method for ERROR ON ERROR
pub fn true_on_error(self) -> Self
pub fn true_on_error(self) -> Self
Convenience method for TRUE ON ERROR
pub fn false_on_error(self) -> Self
pub fn false_on_error(self) -> Self
Convenience method for FALSE ON ERROR
pub fn unknown_on_error(self) -> Self
pub fn unknown_on_error(self) -> Self
Convenience method for UNKNOWN ON ERROR
impl ExistsColumnBuilder<Builder>
impl ExistsColumnBuilder<Builder>
pub fn build_column(self) -> Builder
pub fn build_column(self) -> Builder
Finish building this column and return to the main builder
impl ExistsColumnBuilder<NestedPathBuilder>
impl ExistsColumnBuilder<NestedPathBuilder>
pub fn build_column(self) -> NestedPathBuilder
pub fn build_column(self) -> NestedPathBuilder
Finish building this column and return to the nested path builder